@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 from mopidy import config, ext
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 class Extension(ext.Extension):
@@ -24,4 +24,4 @@ class Extension(ext.Extension):
 
     def setup(self, registry):
         from .app import factory
-        registry.add('http:app', {'name': self.ext_name, 'factory': factory})
+        registry.add('http:app', {'name': 'kuechenradio', 'factory': factory})
